From ebb0fd0a2bd0dc6057cc44b59cd3c37407806d5a Mon Sep 17 00:00:00 2001
From: Your Name
Date: Wed, 5 Mar 2025 09:29:53 +0100
Subject: [PATCH] update
---
loop/SARA_send_data_v2.py | 9 ++++++++-
1 file changed, 8 insertions(+), 1 deletion(-)
diff --git a/loop/SARA_send_data_v2.py b/loop/SARA_send_data_v2.py
index e8270e0..845be4d 100755
--- a/loop/SARA_send_data_v2.py
+++ b/loop/SARA_send_data_v2.py
@@ -600,7 +600,7 @@ try:
print('
')
#Si non ne recoit pas de réponse UHTTPCR
#on a peut etre une ERROR de type "+CME ERROR: No connection to phone"
else:
print('No UUHTTPCR response')
print("Blink red LED")
@@ -639,6 +639,13 @@ try:
print('')
print(responseResetHTTP_profile)
print("
")
+ check_lines = responseResetHTTP_profile.strip().splitlines()
+ for line in check_lines:
+ if "+CME ERROR: Operation not allowed" in line:
+ print('⚠️ATTENTION: CME ERROR⚠️')
+ print('❓Try Reboot the module❓')
+
+
#5. empty json
print("Empty SARA memory:")
@@ -600,7 +600,7 @@ try:
')
#Si non ne recoit pas de réponse UHTTPCR
- #on a peut etre une ERROR de type "+CME ERROR: No connection to phone"
+ #on a peut etre une ERROR de type "+CME ERROR: No connection to phone" ou "Operation not allowed"
else:
print('No UUHTTPCR response')